# Imports de module 
import json 
import requests
import os 

config_file = 'config.json'
required_fields = ['tokenid', 'apikey', 'service']

# Vérifier si le fichier existe
if os.path.isfile(config_file):
    # Le fichier existe, vous pouvez procéder avec la lecture et la vérification des données
    with open(config_file, 'r') as f:
        config = json.loads(f.read())
    
    # Vérifier si les champs requis existent et ne sont pas vides
    if all(field in config and config[field] for field in required_fields):
        class CollectPayment:
            @classmethod
            def initialize(cls, amount, custom_data):
                # Préparation des données 
                url = "https://kaliapay.com/api/generate-mobpay-qrcode/"
                data = {
                    "apikey": config['apikey'],
                    "service": config['service'],
                    "amount": amount,
                    "custom_data": custom_data
                }
                headers = {"Authorization": f"Token {config['tokenid']}"}
                req = requests.post(url, data=data, headers=headers)
                result = {"code": req.status_code, "response": req.json()}
                return result

            @classmethod
            def get_transaction_status(cls, reference):
                headers = {"Authorization": f"Token {config['tokenid']}"}
                url = f"https://kaliapay.com/api/get-express-transaction-details/{reference}/"
                req = requests.get(url, headers=headers)
                return req.json()
        
    else:
        print(f"Le fichier {config_file} ne contient pas toutes les données requises ou certains champs sont vides.")
    
else:
    print(f"Le fichier {config_file} n'existe pas.")
